@@ -23,6 +23,7 @@ from calibre.utils.icu import sort_key
 from calibre.library.comments import comments_to_html
 from calibre.gui2.library.delegates import ClearingDoubleSpinBox, ClearingSpinBox
 from calibre.gui2.widgets2 import RatingEditor
+from polyglot.builtins import unicode_type
 
 
 def safe_disconnect(signal):
@@ -88,7 +89,7 @@ class SimpleText(Base):
         self.widgets = [QLabel('&'+self.col_metadata['name']+':', parent), QLineEdit(parent)]
 
     def setter(self, val):
-        self.widgets[1].setText(type(u'')(val or ''))
+        self.widgets[1].setText(unicode_type(val or ''))
 
     def getter(self):
         return self.widgets[1].text().strip()
@@ -111,7 +112,7 @@ class LongText(Base):
         self.widgets = [self._box]
 
     def setter(self, val):
-        self._tb.setPlainText(type(u'')(val or ''))
+        self._tb.setPlainText(unicode_type(val or ''))
 
     def getter(self):
         return self._tb.toPlainText()
@@ -371,7 +372,7 @@ class Comments(Base):
         self._tb.wyswyg_dirtied()
 
     def getter(self):
-        val = unicode(self._tb.html).strip()
+        val = unicode_type(self._tb.html).strip()
         if not val:
             val = None
         return val
@@ -497,12 +498,12 @@ class Text(Base):
 
     def getter(self):
         if self.col_metadata['is_multiple']:
-            val = unicode(self.widgets[1].text()).strip()
+            val = unicode_type(self.widgets[1].text()).strip()
             ans = [x.strip() for x in val.split(self.sep['ui_to_list']) if x.strip()]
             if not ans:
                 ans = None
             return ans
-        val = unicode(self.widgets[1].currentText()).strip()
+        val = unicode_type(self.widgets[1].currentText()).strip()
         if not val:
             val = None
         return val
@@ -571,7 +572,7 @@ class Series(Base):
         self.initial_val, self.initial_index = self.current_val
 
     def getter(self):
-        n = unicode(self.name_widget.currentText()).strip()
+        n = unicode_type(self.name_widget.currentText()).strip()
         i = self.idx_widget.value()
         return n, i
 
@@ -643,7 +644,7 @@ class Enumeration(Base):
         self.widgets[1].setCurrentIndex(self.widgets[1].findText(val))
 
     def getter(self):
-        return unicode(self.widgets[1].currentText())
+        return unicode_type(self.widgets[1].currentText())
 
     def normalize_db_val(self, val):
         if val is None:
@@ -836,7 +837,7 @@ class BulkBase(Base):
                 break
         ans = None
         if len(values) == 1:
-            ans = iter(values).next()
+            ans = next(iter(values))
         if isinstance(ans, frozenset):
             ans = list(ans)
         return ans
@@ -1164,7 +1165,7 @@ class BulkSeries(BulkBase):
         self.a_c_checkbox.setChecked(False)
 
     def getter(self):
-        n = unicode(self.main_widget.currentText()).strip()
+        n = unicode_type(self.main_widget.currentText()).strip()
         autonumber = self.idx_widget.checkState()
         force = self.force_number.checkState()
         start = self.series_start_number.value()
@@ -1234,7 +1235,7 @@ class BulkEnumeration(BulkBase, Enumeration):
         self.main_widget.blockSignals(False)
 
     def getter(self):
-        return unicode(self.main_widget.currentText())
+        return unicode_type(self.main_widget.currentText())
 
     def setter(self, val):
         if val is None:
@@ -1355,10 +1356,10 @@ class BulkText(BulkBase):
         if self.col_metadata['is_multiple']:
             if not self.col_metadata['display'].get('is_names', False):
                 return self.removing_widget.checkbox.isChecked(), \
-                        unicode(self.adding_widget.text()), \
-                        unicode(self.removing_widget.tags_box.text())
-            return unicode(self.adding_widget.text())
-        val = unicode(self.main_widget.currentText()).strip()
+                        unicode_type(self.adding_widget.text()), \
+                        unicode_type(self.removing_widget.tags_box.text())
+            return unicode_type(self.adding_widget.text())
+        val = unicode_type(self.main_widget.currentText()).strip()
         if not val:
             val = None
         return val
